==> img0ch-3.0.1.tar.bz2: img0ch/_template/default/subback.cs <==
<html>
<head>
<title><?cs var:html_escape(BBS_TITLE) ?>Xbhꗗ</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
function redir(element) {
    app.redirectRenderer(element);
    return true;
}
//-->
</script>
<?cs var:META ?>
</head>
<body bgcolor="white">
<small>
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><hr><?cs /if ?>
<?cs each:item = Threads ?>
<a href="<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/l50" target="_blank" onclick="redir(this)"><?cs var:html_escape(item.index) ?>:<?cs var:html_escape(item.subject) ?> (<?cs var:html_escape(item.res) ?>)</a>
<?cs /each ?>
<div align=right>
<a href="<?cs var:html_escape(BBSURI) ?>/kako/index.html" target=_blank><b>ߋOqɂ͂</b></a><br>
<?cs var:html_escape(VERSION) ?>
</div>
</small>
</body>
</html>

==> img0ch-3.1.11.tar.bz2: img0ch/_template/default/subback.cs <==
<html>
<head>
<title><?cs var:html_escape(BBS_TITLE) ?>Xbhꗗ</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
function redir(element) {
    app.redirectRenderer(element);
    return true;
}
//-->
</script>
<?cs var:META ?>
</head>
<body bgcolor="white">
<small>
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><hr><?cs /if ?>
<?cs each:item = Threads ?>
<a href="<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/l50" target="_blank" onclick="redir(this)"><?cs var:html_escape(item.index) ?>:<?cs var:item.subject ?> (<?cs var:html_escape(item.res) ?>)</a>
<?cs /each ?>
<div align=right>
<a href="<?cs var:html_escape(BBSURI) ?>/kako/index.html" target=_blank><b>ߋOqɂ͂</b></a><br>
<?cs var:html_escape(VERSION) ?>
</div>
</small>
</body>
</html>
